// @ts-nocheck
import * as tl from 'vsts-task-lib/task';

import { OPENSSL, ARGS, KEYOUT_NAME_ARG, OUT_CERT_NAME_ARG, OPENSSL_COMMAND } from '../constants/index';
import { ICertKeyRequest } from '../interfaces/index';

export class Openssl {
    private command = OPENSSL;

    private opensslCommand = OPENSSL_COMMAND;

    private args = ARGS;

    private keyNameArg = KEYOUT_NAME_ARG;

    private certNameArg = OUT_CERT_NAME_ARG;

    private name: string;

    private expiry: string;

    constructor(certKeyRequest: ICertKeyRequest) {
        this.name = certKeyRequest.name;
        this.expiry = certKeyRequest.expiry;
    }

    public async request(certKeyRequest: ICertKeyRequest) {
        try {
            const openssl = new Openssl(certKeyRequest);
            const allArgs: any[] = ['req'];
            this.args.map((item) => allArgs.push(item));
            allArgs.push(this.expiry);
            allArgs.push(this.keyNameArg);
            allArgs.push(`${this.name}.key`);
            allArgs.push(this.certNameArg);
            allArgs.push(`${this.name}.cert`);
            await tl.exec(tl.which(openssl.command), allArgs).fail((err) => {
                throw new Error(`exec command failed with error${err}`);
            });
        } catch (err) {
            tl.setResult(tl.TaskResult.Failed, err.message);
            console.error(err);
            throw new Error(err);
        }
    }
}
